@@ -8,10 +8,10 @@ use Coro;
 use Coro::Channel;
 use Coro::Storable qw(freeze thaw);
 use MIME::Base64 qw(encode_base64 decode_base64);
-use Sys::CPU;
+use Sys::Info;
 use Coro::ProcessPool::Process;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
@@ -29,13 +29,21 @@ use fields qw(
 sub new {
     my ($class, %param) = @_;
     my $self = fields::new($class);
-    $self->{max_procs} = $param{max_procs} || Sys::CPU::cpu_count();
+    $self->{max_procs} = $param{max_procs} || _cpu_count();
     $self->{max_reqs}  = $param{max_reqs}  || 0;
     $self->{num_procs} = 0;
     $self->{procs}     = Coro::Channel->new();
     return $self;
 }
 
+#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------------
+sub _cpu_count {
+    my $info = Sys::Info->new();
+    my $cpu  = $info->device('CPU');
+    return $cpu->count;
+}
+
 #-------------------------------------------------------------------------------
 #-------------------------------------------------------------------------------
 sub shutdown {
@@ -138,7 +146,8 @@ Creates a new process pool. Processes will be spawned as needed.
 
 This is the maximum number of child processes to maintain. If all processes are
 busy handling tasks, further calls to L<./process> will yield until a process
-becomes available.
+becomes available. If not specified, defaults to the number of CPUs on the
+system.
 
 =item max_reqs
 
